@@ -1,4 +1,5 @@
 
+
 #[derive(Debug, thiserror::Error)]
 pub enum GoogError {
     #[error(r#"Error while running "go init"#)]
@@ -6,5 +7,7 @@ pub enum GoogError {
     #[error("Command or Arg not found")]
     GoogNotFound,
     #[error("Open Browser Error")]
-    GoogBrowserError(#[from] std::io::Error)
-}
\ No newline at end of file
+    GoogBrowserError(#[from] std::io::Error),
+    #[error("Missing a required Arg")]
+    GoogArgNotSupplied
+}
